@@ -5,7 +5,6 @@
 from .field_model import FieldModel
 from .hashable_model import HashableModel
 from .model_params import ModelParams
-from .note import Note
 from .operable_model import OperableModel
 from .schema_model import SchemaModel
 
@@ -13,7 +12,6 @@ __all__ = (
     "FieldModel",
     "ModelParams",
     "OperableModel",
-    "Note",
     "SchemaModel",
     "HashableModel",
 )
