@@ -2,11 +2,11 @@
 #
 # SPDX-License-Identifier: Apache-2.0
 
-from .brainstorm.brainstorm import BrainstormOperation, brainstorm
 from .builder import ExpansionStrategy, OperationGraphBuilder
 from .flow import flow
 from .node import BranchOperations, Operation
-from .plan.plan import PlanOperation, plan
+
+Builder = OperationGraphBuilder
 
 __all__ = (
     "ExpansionStrategy",
@@ -15,8 +15,5 @@ __all__ = (
     "flow",
     "BranchOperations",
     "Operation",
-    "plan",
-    "PlanOperation",
-    "brainstorm",
-    "BrainstormOperation",
+    "Builder",
 )
