@@ -1,19 +1,10 @@
 # Copyright (c) 2025, HaiyangLi <quantocean.li at gmail dot com>
 # SPDX-License-Identifier: Apache-2.0
 
-from lionagi.protocols.types import DataLogger
-
 from ._types import AssosiatedEventInfo, HookDict, HookEventTypes
 from .hook_event import HookEvent
 from .hook_registry import HookRegistry
-
-global_hook_logger = DataLogger(
-    persist_dir="./data/logs",
-    subfolder="hooks",
-    file_prefix="hook",
-    capacity=1000,
-)
-
+from .hooked_event import HookedEvent, global_hook_logger
 
 __all__ = (
     "HookEventTypes",
@@ -22,4 +13,5 @@ __all__ = (
     "HookEvent",
     "HookRegistry",
     "global_hook_logger",
+    "HookedEvent",
 )
